# WARNING: Please don't edit this file. It was generated by Python/WinRT v3.0.0

import winrt.system
from winrt._winrt_windows_perception_automation_core import (
    CorePerceptionAutomation,
)

__all__ = [
    "CorePerceptionAutomation",
]




# WARNING: Please don't edit this file. It was generated by Python/WinRT v3.0.0

import datetime
import sys
import types
import typing
import uuid as _uuid
from builtins import property as _property

import winrt._winrt
import winrt.system
import winrt.windows.foundation as windows_foundation

Self = typing.TypeVar('Self')

@typing.final
class CorePerceptionAutomation_Static(winrt._winrt.IInspectable_Static):
    # System.Void Windows.Perception.Automation.Core.CorePerceptionAutomation::SetActivationFactoryProvider(Windows.Foundation.IGetActivationFactory)
    def set_activation_factory_provider(cls, provider: windows_foundation.IGetActivationFactory, /) -> None: ...

@typing.final
class CorePerceptionAutomation(winrt.system.Object, metaclass=CorePerceptionAutomation_Static):
    pass

